
clear
cd c:\papers\yunproject
set more off
log using mvdcmp_exampleVersion10IC.log, replace
use lnwage

***************************************************
* first compare mvdcmp regression results to oaxaca
****************************************************

gen ed1 = cond(educ < 12, 1, 0)
gen ed2 = cond(educ == 12, 1, 0)
gen ed3 = cond(educ > 12, 1, 0)

oaxaca lnwage educ exper tenure [pw=wt], by(female) det weight(1) fixed
mvdcmp female, reverse : regress lnwage educ exper tenure [pw=wt]

*******************
* try normalization
*******************

oaxaca lnwage ed1 ed3 exper tenure [pw=wt], by(female) det weight(1) fixed cat(ed1 ed2 ed3)
mvdcmp female, reverse norm(ed1 ed2 ed3): regress lnwage ed1 ed3 exper tenure [pw=wt]

**************************
* binary response models
**************************

use pmbNLSY, clear
* illustrate logit decomposition
gen medu1 = 0
 replace medu1 = 1 if medu < 12
gen medu2 = 0
 replace medu2 = 1 if medu == 12
gen medu3 = 0
 replace medu3 = 1 if medu > 12

bysort blk: sum devnt nfamtran medu1 medu2 medu3 inc1000 magebir , separator(1000)

* make dummy weights using adjusted income
* fake fw
gen f = round(inc1000) + 1
* fake pw
gen p = f/6

logit devnt nfamtran medu1 medu3 inc1000 magebir if blk==0
logit devnt nfamtran medu1 medu3 inc1000 magebir if blk==1

*******************
* compare to oaxaca
*******************

mvdcmp blk: logit devnt nfamtran medu1 medu3 inc1000 magebir
oaxaca devnt nfamtran medu1 medu3 inc1000 magebir, by(blk) det weight(1) fixed logit swap


************************************
* test weights and compare to oaxaca 
************************************

mvdcmp blk: logit devnt nfamtran medu1 medu3 inc1000 magebir [fw=f]
oaxaca devnt nfamtran medu1 medu3 inc1000 magebir [fw=f], by(blk) det weight(1) fixed logit swap
mvdcmp blk: logit devnt nfamtran medu1 medu3 inc1000 magebir [pw=p]
oaxaca devnt nfamtran medu1 medu3 inc1000 magebir [pw=p], by(blk) det weight(1) fixed logit swap

*********************
* compare to fairlie 
*********************

fairlie devnt nfamtran medu1 medu3 inc1000 magebir [fw=f], by(blk) reference(1)  ro reps(400)  
fairlie devnt nfamtran medu1 medu3 inc1000 magebir [pw=p], by(blk) reference(1)  ro reps(400)  

****************************************
* compare to fairlie with grouping
****************************************

mvdcmp blk: logit devnt nfamtran medu1 medu3 inc1000 magebir 
mvdcmpgroup (SES: medu1 medu3 inc1000)


fairlie devnt nfamtran (SES: medu1 medu3 inc1000) magebir, by(blk) reference(1)  ro reps(400)  

***************************************
* try norm option and compare to oaxaca (normalize)
***************************************

mvdcmp blk, norm(medu1 medu2 medu3): logit devnt nfamtran medu1 medu3 inc1000 magebir 
oaxaca devnt nfamtran normalize(medu1 medu2 medu3) inc1000 magebir, by(blk) det weight(1) fixed logit swap

****************************************************
* test probit: compare to fairlie, & oaxaca 
****************************************************

mvdcmp blk: probit devnt nfamtran medu1 medu3 inc1000 magebir
oaxaca devnt nfamtran medu1 medu3 inc1000 magebir, by(blk) det weight(1) fixed probit swap
fairlie devnt nfamtran medu1 medu3 inc1000 magebir, probit by(blk) reference(1)  ro reps(100)  

***********
* test cll
***********

mvdcmp blk: cloglog devnt pctsmom nfamtran medu1 medu3 inc1000 nosibs magebir 

* check overall against nldecompose *

nldecompose, by(blk): logit devnt pctsmom nfamtran medu1 medu3 inc1000 nosibs magebir 
nldecompose, by(blk): probit devnt pctsmom nfamtran medu1 medu3 inc1000 nosibs magebir 


***********************
* count and rate models
***********************

use nabort, clear

bysort consprot: sum nabort npreg medu adjinc south profam books 
 
gen rabort = nabort/npreg
sum rabort if consprot==0
scalar r0 = r(mean) 
sum rabort if consprot==1
scalar r1 = r(mean) 
scalar Dr01 = 100* (r0 - r1)
*****this is the difference in overall rates to decompose (scaled X 100)*****
scalar list Dr01
sum nabort if consprot==0
scalar d0 = r(mean) 
sum nabort if consprot==1
scalar d1 = r(mean) 
scalar Dd01 = (d0 - d1)
*****this is the difference in overall counts to decompose*****
scalar list Dd01

*****************
* poisson
* rates 
*****************
* for testing 
mvdcmp consprot, reverse : poisson nabort medu adjinc south urban profam books, offset(lognpreg) 

mvdcmp consprot, scale(100) reverse : poisson nabort medu adjinc south urban profam books, offset(lognpreg) 
mvdcmpgroup (SES: medu adjinc books)

********
*counts
********

mvdcmp consprot, reverse: poisson nabort medu adjinc south urban profam books
mvdcmpgroup (SES: medu adjinc books)

* gdecomp no longer appears to work
* gdecomp consprot: poisson nabort medu adjinc south urban profam books
*
*****************
* nbreg
* rates 
*****************
* as in paper
use nabort, clear

******************
*negative binomial
******************

mvdcmp consprot,  reverse scale(100) : poisson nabort medu adjinc south urban profam books, offset(lognpreg) 

********
*counts
********

mvdcmp consprot, reverse: nbreg nabort medu adjinc south urban profam books
* gdecomp no longer works
* gdecomp consprot: nbreg nabort medu adjinc south urban profam books
*

* check overall against nldecompose *

nldecompose, by(consprot): nbreg nabort medu adjinc south urban profam books
 
********************************************
* try a test with some frequency table data
********************************************

use pmbNLSY, clear
* illustrate logit decomposition on frequency table
gen medu1 = 0
 replace medu1 = 1 if medu < 12
gen medu2 = 0
 replace medu2 = 1 if medu == 12
gen medu3 = 0
 replace medu3 = 1 if medu > 12
gen youngmom = 0
 replace youngmom = 1 if magebir < 20
gen famtran0 = 0
  replace famtran0 = 1 if nfamtran == 0
gen famtran2 = 0
  replace famtran2 = 1 if nfamtran >= 2
gen famtran1 = 0
  replace famtran1 = 1 if nfamtran == 1
gen ftran = cond(nfamtran > 0,1,0)

************************
* individual-level data
************************

mvdcmp blk: logit devnt medu1 youngmom ftran

* also worth trying binary Poisson here

mvdcmp blk: poisson devnt medu1 youngmom ftran


contract blk devnt medu1 youngmom ftran, zero freq(f)

************************************************
* grouped data (frequency weights = replicates)
* data are in the form of a contingency table
* note: pwieghts used for illustration only 
************************************************
sum f
gen D = r(sum)
gen p = f/D
logit devnt medu1 youngmom ftran [fw=f] if blk==0
logit devnt medu1 youngmom ftran [fw=f] if blk==1
mvdcmp blk: logit devnt medu1 youngmom ftran [fw=f]
oaxaca devnt medu1 youngmom ftran [fw=f], by(blk) det weight(1) fixed logit swap

* try Poisson here 

poisson devnt medu1 youngmom ftran [fw=f] if blk==0
poisson devnt medu1 youngmom ftran [fw=f] if blk==1
mvdcmp blk: poisson devnt medu1 youngmom ftran [fw=f]


******************************************************************
* robust se's using in modeling with pw lead to much larger se's 
* compared to results using frequency weights
* frequency weight analysis matches individual analysis above 
******************************************************************
logit devnt medu1 youngmom ftran [pw=p] if blk==0
logit devnt medu1 youngmom ftran [pw=p] if blk==1
mvdcmp blk: logit devnt medu1 youngmom ftran [pw=p]


log close